
Welcome to syndantic's documentation!
=====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   user_guide
   tutorials
   faq


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. sidebar-links::
   :caption: Project Links
   :github:
   :pypi: syndantic
